Struct tc_state::closure::Closure

source ·
pub struct Closure { /* private fields */ }
An OpDef which closes over zero or more States

Implementations

source

impl Closure

source

pub fn into_inner(self) -> (Map<State>, OpDef)

Return the context and OpDef which define this Closure.

source

pub fn dereference_self(self, path: &TCPathBuf) -> Self

Replace references to $self with the given path.

source

pub fn is_inter_service_write(&self, cluster_path: &[PathSegment]) -> bool

Return true if this Closure may write to service other than where it’s defined

source

pub fn reference_self(self, path: &TCPathBuf) -> Self

Replace references to the given path with $self

source

pub async fn call(self, txn: &Txn, args: State) -> TCResult<State>

Execute this Closure with the given args

source

pub async fn call_owned(self, txn: Txn, args: State) -> TCResult<State>

Execute this Closure with an owned Txn and the given args.